anirent

package module
v0.0.0-...-1944ea0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2022 License: MIT Imports: 22 Imported by: 0

README

Anirent

anirent is a tool for querying various torrent search engines for anime.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service struct {
	pb.UnimplementedAnirentServer
	// contains filtered or unexported fields
}

Service

func NewService

func NewService() (*Service, error)

NewService

func (*Service) Download

func (s *Service) Download(ctx context.Context, req *pb.DownloadRequest) (*pb.DownloadResponse, error)

Download

func (*Service) Search

func (s *Service) Search(req *pb.SearchRequest, stream pb.Anirent_SearchServer) error

Search

func (*Service) Serve

func (s *Service) Serve(ctx context.Context) error

Serve handles the initialization of the underlying gRPC server and registering the Anirent Server service with it. It then begins serving requests. The provided context can be used to gracefully shutdown the server.

func (*Service) Subscribe

func (s *Service) Subscribe(req *pb.Subscription, stream pb.Anirent_SubscribeServer) error

Subscribe

Directories

Path Synopsis
cmd
anirent command

Jump to