Documentation
¶
Index ¶
- type Service
- func (s *Service) Download(ctx context.Context, req *pb.DownloadRequest) (*pb.DownloadResponse, error)
- func (s *Service) Search(req *pb.SearchRequest, stream pb.Anirent_SearchServer) error
- func (s *Service) Serve(ctx context.Context) error
- func (s *Service) Subscribe(req *pb.Subscription, stream pb.Anirent_SubscribeServer) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
pb.UnimplementedAnirentServer
// contains filtered or unexported fields
}
Service
func (*Service) Download ¶
func (s *Service) Download(ctx context.Context, req *pb.DownloadRequest) (*pb.DownloadResponse, error)
Download
func (*Service) Search ¶
func (s *Service) Search(req *pb.SearchRequest, stream pb.Anirent_SearchServer) error
Search
func (*Service) Serve ¶
Serve handles the initialization of the underlying gRPC server and registering the Anirent Server service with it. It then begins serving requests. The provided context can be used to gracefully shutdown the server.
func (*Service) Subscribe ¶
func (s *Service) Subscribe(req *pb.Subscription, stream pb.Anirent_SubscribeServer) error
Subscribe
Click to show internal directories.
Click to hide internal directories.